clear all, close all

%%% PARAMETERS %%%
nGauss=5;  %Gauss Legendre quadrature parameters

analyt=0;  %If analytical solution is tested or not

nRef=5;    %Number of refinements

%%% EQUATION SETUP %%%
%Depends on if analytical solution is used or not.
if analyt
    freq1=2*pi;
    freq2=1*pi;
    
    uex=@(x) sin(freq1*x(:,1)).*sin(freq2*x(:,2));
    gradux=@(x)[ ... ... ];
    alpha=@(x)...
    f=@(x,flag)...;
else
    lam=2/3;
    uex=@(x)(x(:,1)-a).^lam;
    gradux=@(x)[...];
    alpha=@(x) ...;
    f=@(x,flag)...
end
    
Dir=uex;

%%% MESH IMPORT %%%
load quadMesh_Square.mat
    

%%% REFINEMENT LOOP %%%
for ref=1:nRef
    disp(['REFINEMENT STEP ', num2str(ref), '...'])
    
    %%% REFINE THE INITIAL MESH USING refine_REG.m %%%
    Mesh=...
    
    %%% ASSEMBLY OF MATRICES %%%
    QuadRule=... %Tensorize gauleg(0,1,NGauss)
    
    M=...
    K=...
    A=M+K;
    
    l=...
    
    %%% MANIPULATE A,l FOR DIRICHLET B.C. %%%
    DirEdges=... %Edges where Dirichlet conditions are imposed
    idxBddofs=... %Dofs where Dirichlet cond. are imposed
    E=speye(size(M,1)); %Identity matrix
    A(idxBddofs,:)=...
    l(idxBddofs)=Dir(...);
    
    %%% SOLVE EQUATION %%%
    uh=...
    
    %%% COMPUTE H^1 ERROR %%%
    err(ref) = ...
    h(ref)=...
end
disp('-----------------------------')

%%% PLOT %%%
figure(2)
loglog(h, err, 'ko:', h, h, 'k-')
legend('Experimental error', 'linear Convergence','Location','SouthEast')
xlabel('h')
ylabel('Error in H^1-norm')


%%% RATE FIT %%%
r=polyfit(...);
disp(['ESTIMATED CONVERGENCE RATE: ', num2str(...)])